@@ -13,7 +13,7 @@ test_that("example works", {
   
   skip_if_offline()
 
-  results <- GNRS(political_division_dataframe = gnrs_testfile)
+  results <- GNRS(political_division_dataframe = gnrs_testfile, url = url)
   
   expect_equal(object = class(results), expected = "data.frame")
   
@@ -22,7 +22,8 @@ test_that("example works", {
   results <- GNRS_super_simple(
                 country = "United States",
                 state_province = "Arizona",
-                county_parish = "Pima County")
+                county_parish = "Pima County",
+                url = url)
   
   expect_equal(object = class(results), expected = "data.frame")
 
@@ -35,7 +36,8 @@ test_that("bad input returns error", {
   
   skip_if_offline()
   
-  expect_error(object = GNRS(political_division_dataframe = 1))  
+  expect_error(object = GNRS(political_division_dataframe = 1,
+                             url = url))  
   
 
 })
\ No newline at end of file
