@@ -5,7 +5,7 @@ test_that("example works", {
   
   skip_if_offline()
   
-  results <- GNRS_super_simple(country = "United States of America")
+  results <- GNRS_super_simple(country = "United States of America", url = url)
   
   expect_equal(object = class(results), expected = "data.frame")
 
@@ -15,7 +15,8 @@ test_that("example works", {
   results <- GNRS_super_simple(
                 country = "United States",
                 state_province = "Arizona",
-                county_parish = "Pima County")
+                county_parish = "Pima County",
+                url = url)
   
 
   expect_equal(object = class(results), expected = "data.frame")
@@ -33,7 +34,8 @@ test_that("bad input returns no match", {
     GNRS_super_simple(country = "Autobot",
                       state="Optimus",
                       county_parish = "Prime",
-                      user_id = 2005)
+                      user_id = 2005,
+                      url = url)
   
   expect_equal(object = nonsense_query$match_status,
                expected = "no match")
@@ -48,10 +50,12 @@ test_that("Good input returns a match", {
     GNRS_super_simple(country = "USA",
                       state="Michigan",
                       county_parish = "Kent",
-                      user_id = 616)
+                      user_id = 616,
+                      url = url)
   
   expect_equal(object = sensible_query$match_status,
-               expected = "full match")
+               expected = "full match",
+               url = url)
   
 })
 
